#+TITLE: Perché Org-Mode ti cambierà la vita
#+AUTHOR: Leonardo Tamiano
#+OPTIONS: num:nil toc:1
#+REVEAL_THEME: cyberpunk
#+REVEAL_TRANS: linear
#+REVEAL_EXTRA_CSS: local.css

* Che Cos'è Org-mode?
  #+REVEAL: split
  
  *Org-mode* può essere visto da due punti di vista diversi:

  1. Come *markup language*.

  2. Come *major-mode* in Emacs.

  #+REVEAL: split

  I file *.org* sono *plaintext* files che possono essere processati in
  modo dinamico tramite Emacs.

  #+REVEAL_HTML: <div>
   
  #+REVEAL_HTML: <div class="column" style="float:left; width:50%">
  #+REVEAL_HTML: <img src="./images/org_mode_01.png">
  #+REVEAL_HTML: <p style="margin-top:-20px; font-size:20px;"> Plaintext </p>  
  #+REVEAL_HTML: </div>
   
  #+REVEAL_HTML: <div class="column" style="float:right; width:50%">
  #+REVEAL_HTML: <img src="./images/org_mode_02.png">
  #+REVEAL_HTML: <p style="margin-top:-20px; font-size:20px;"> Org-mode (in emacs) </p>
  #+REVEAL_HTML: </div>
   
  #+REVEAL_HTML: </div>

  #+REVEAL: split

  Detto questo, non è necessario utilizzare Emacs per scrivere/leggere
  i files in org-mode. Esistono anche supporti in altri
  tools/librerie, come ad esempio in python.

  #+begin_src python
# This function takes a node of an org-file
# and returns the content of all the headings
# in the org file as a formatted string.
def create_toc_body(node, depth):
    if len(node.children) == 0:
        return ""

    res = ""
    spaces = " " * depth * 2
    for child in node.children:
        # remove bold characters *
        heading = child.get_heading().replace("*", "")
        res = res + spaces + "- " + heading + "\n"
        res = res + create_toc_body(child, depth+1)
    return res
  #+end_src

  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://pypi.org/project/orgparse/"> orgparse </a> </p>

  #+REVEAL: split

  La particolare sintassi utilizzata è detta *Org-Mode Markup Language*,
  e rappresenta la parte più importante di org-mode.

  #+begin_example
,* This Is A Heading
,** This Is A Sub-Heading
,*** And A Sub-Sub-Heading
    Paragraphs are separated by at least one empty line.
    
    ,*bold* /italic/ _underlined_ +strikethrough+ =monospaced=
    [[http://Karl-Voit.at][Link description]]
    http://Karl-Voit.at → link without description

    - list item
      - sub-item
	1. also enumerated
    - [ ] yet to be done
    - [X] item which is done

    : Simple pre-formatted text such as for source code.
  #+end_example

  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://karl-voit.at/2017/09/23/orgmode-as-markup-only/"> karl-voit - Org Mode Is One of the Most Reasonable Markup Languages to Use for Text </a> </p>
  
* Storia
  #+REVEAL: split
  
  *Org-mode* nasce nel 2003 da *Carsten Dominik*.

  #+REVEAL_HTML: <img src="./images/carsten_dominik.png" class="scratch" height=400px;>
  
  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://staff.fnwi.uva.nl/c.dominik/"> Carsten Dominik blog </a> </p>

  #+REVEAL: split

  Dalle parole di Dominik:

  #+begin_quote
Org was born in 2003, out of frustration over the user interface of
the Emacs Outline mode. I was trying to organize my notes and
projects, and using Emacs seemed to be the natural way to go [...]
  #+end_quote

  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://orgmode.org/manual/History-and-Acknowledgments.html"> orgmode manual </a> </p>
  
  #+REVEAL: split
  
  #+begin_quote
[...] Visibility cycling and structure editing were originally
implemented in the package ‘outline-magic.el’, but quickly moved to
the more general ‘org.el’ [...]
  #+end_quote

  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://orgmode.org/manual/History-and-Acknowledgments.html"> orgmode manual </a> </p>
  
  #+REVEAL: split
  
  #+begin_quote
[...] These areas highlighted the two main goals that Org still has
today: to be a new, outline-based, plain text mode with innovative and
intuitive editing features, and to incorporate project planning
functionality directly into a notes file.
  #+end_quote
  
  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://orgmode.org/manual/History-and-Acknowledgments.html"> orgmode manual </a> </p>

  #+REVEAL: split

  A partire del 2006 *org-mode* è strato introdotto come major-mode
  all'interno di Emacs.

  *Bastien Guerry* è il maintainer corrente di org-mode.
  
* Use Cases Generali
  #+REVEAL: split
  *Org-mode* può essere principalmente utilizzato per:

  - *Document outlining*.
  - *Personal Information Management (PIM)*.
  - *Literate Programming*.
  - *Publishing/Exporting tool*.

  Ma questo è solo l'inizio. Sono tanti gli altri possibili use-cases
  per org-mode...

** Document Outlining
   #+REVEAL: split   
   Tramite le *headlines* siamo in grado di

   - strutturare un testo di qualsiasi natura.

   - visualizzare in modo dinamico la parte del testo a cui siamo
     interessati.

   - modificare in modo dinamico la struttura delle varie headlines.

   #+REVEAL: split

   #+REVEAL_HTML: <img src="./images/document_outlining_02.gif" class="scratch">

  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Utilizzo dinamico delle headlines in org-mode  </p>   
  
** Personal Information Management
   #+REVEAL: split
   La semplicità e flessibilità di org-mode permettono di gestire:

   - TODOs/appuntamenti (*org-agenda*).
   - Contatti.
   - Appunti per progetti.
   - Basi di conoscenza. (*org-brain*, *org-roam*)

   e in generale tutti i task che necessitano di prendere appunti.

*** org-agenda
    #+REVEAL: split
    Per settare i file da cui prendere i dati bisogna eseguire il
    seguente codice elisp

    #+begin_src elisp
(setq org-agenda-files (list "~/agenda.org"
			     "~/work.org"))
    #+end_src

    #+REVEAL: split
    
    Una volta fatto questo possiamo editare il file ~agenda.org~
    aggiungendo vari TODOs, a seconda dei nostri impegni.
   
    #+REVEAL_HTML: <img src="./images/org_agenda_01.img" class="scratch" height=400px;>

    #+REVEAL: split

    Per avere una overview di tutti i nostri impegni (presenti anche
    in vari files), possiamo eseguire il comando ~(org-agenda)~.

    #+REVEAL_HTML: <img src="./images/org_agenda_02.img" class="scratch" height=400px;>

    #+REVEAL: split

    #+REVEAL_HTML: <img src="./images/org_agenda_03.img" class="scratch" height=400px;>

*** contacts
    #+REVEAL: split
    Ciascuna headline può contenere vari *attributi*, che possono essere
    utilizzati, ad esempio, per memorizzare le informazioni dei
    contatti.

    #+REVEAL_HTML: <img src="./images/org_contacts.png" class="scratch" height=400px;>    

*** knowledge bases
    #+REVEAL: split
    Uno degli utilizzi più complessi di org-mode riguarda la creazione
    di basi di conoscenza personali. 

    - [[https://github.com/org-roam/org-roam][org-roam]]
    - [[https://github.com/Kungsgeten/org-brain][org-brain]]

** Literate Programming
   #+REVEAL: split
   Tramite la componente *org-babel* di org-mode si è in grado di
   inserire del codice eseguibile in mezzo a del testo normale.

   #+REVEAL_HTML: <img src="./images/org_babel_01.png" class="scratch" height=450px;>

   #+REVEAL: split

   Sono vari i linguaggi supportati da *org-babel*.

   #+REVEAL_HTML: <img src="./images/org_babel_02.png" class="scratch" height=500px;>
   
** Publishing/Exporting Tool
   #+REVEAL: split
   
   I file org-mode possono poi essere *esportati* in altri formati. Tra
   i formati di esportazione troviamo:

   - HTML.
   - LaTeX (.tex, .pdf).
   - Markdown.
   - iCalendar.
   - Plaintext.

   il comando per fare questo è

   ~(org-export-dispatch)~

   bindato al keybind ~C-c C-e~.

   #+REVEAL: split

   #+REVEAL_HTML: <img src="./images/org_exporting_01.png" class="scratch" width=600px;>

   #+REVEAL: split

   Ad esempio,

   #+REVEAL_HTML: <div>
   #+REVEAL_HTML: <div class="column" style="float:left; width:40%">
   #+REVEAL_HTML: <img src="./images/org_exporting_02.png">
   #+REVEAL_HTML: <p style="margin-top:-20px; font-size:20px;"> file .org </p>     
   #+REVEAL_HTML: </div>

   #+REVEAL_HTML: <div class="column" style="float:left;margin-top:130px; margin-left:50px;">
   $$\longrightarrow$$
   #+REVEAL_HTML: </div>
  
   #+REVEAL_HTML: <div class="column" style="float:right; width:40%">
   #+REVEAL_HTML: <img src="./images/org_exporting_03.png">
   #+REVEAL_HTML: <p style="margin-top:-20px; font-size:20px;"> file .html </p>        
   #+REVEAL_HTML: </div>
   #+REVEAL_HTML: </div>

   #+REVEAL: split

   Questa *stessa presentazione* è stata ottenuta esportando un file
   *.org* tramite il pacchetto [[https://github.com/hexmode/ox-reveal][ox-reveal]].

   #+REVEAL_HTML: <div>
   #+REVEAL_HTML: <div class="column" style="float:left; width:40%">
   #+REVEAL_HTML: <img src="./images/org_exporting_04.png">
   #+REVEAL_HTML: </div>

   #+REVEAL_HTML: <div class="column" style="float:left;margin-top:130px; margin-left:50px;">
   $$\longrightarrow$$
   #+REVEAL_HTML: </div>
  
   #+REVEAL_HTML: <div class="column" style="float:right; width:40%">
   #+REVEAL_HTML: <img src="./images/org_exporting_05.png">
   #+REVEAL_HTML: </div>
   #+REVEAL_HTML: </div>
   
* Use Cases Personali
  #+REVEAL: split

  Personalmente utilizzo org-mode per un sacco di cose. Tra queste le
  più importanti attualmente sono:

  - Note libri.
  - Note università.
  - Gestione blog.
  - Presentazioni.
  - Appunti macchine HTB.
  - Gestione video YT.

** Knowledge base

*** University Notes
    #+REVEAL: split
    Per ogni materia che studio ho uno o più files *.org*.

    #+REVEAL_HTML: <img src="./images/uni_notes_01.png" class="scratch" height=500px;>
    
    #+REVEAL: split
    
    Il file principale di ogni materia contiene i puntatori ai files
    che contengono gli appunti delle lezioni.

    #+REVEAL_HTML: <div>
    #+REVEAL_HTML: <div class="column" style="float:left; width:50%">
    #+REVEAL_HTML: <img src="./images/uni_notes_02.png" class="scratch">
    #+REVEAL_HTML: </div>
    
    #+REVEAL_HTML: <div class="column" style="float:right; width:50%">
    #+REVEAL_HTML: <img src="./images/uni_notes_03.png" class="scratch">
    #+REVEAL_HTML: </div>
    #+REVEAL_HTML: </div>

    #+REVEAL: split

    In singoli file vengono poi esportati in formato ~.html~ per poterli
    condividere e per poter leggere meglio le formule matematiche
    tramite il pacchetto [[https://github.com/marsmining/ox-twbs][ox-twbs]].

    #+REVEAL_HTML: <img src="./images/uni_notes_04.png" class="scratch" height=400px;>

    #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://leonardotamiano.xyz/ppa/education/university/master/AR/lecture_notes/ar_18.html"> leonardotamiano.xyz </a> </p>    

*** Books
   #+REVEAL: split
   Durante la lettura ogni tanto mi segno degli appunti in un file
   ~.org~ appropriato.

    #+REVEAL_HTML: <img src="./images/book_notes.png" class="scratch" height=500px;>
   
** Blog
   #+REVEAL: split
   La parte principale del mio blog la gestisco tramite un singolo
   file ~.org~ tramite il pacchetto [[https://github.com/kaushalmodi/ox-hugo][ox-hugo]].
 
   #+REVEAL_HTML: <img src="./images/blog.png" class="scratch" height=500px;>
   
** Presentations
   #+REVEAL: split
   Le presentazioni le scrivo tutte in file ~.org~ e le esporto in
   ~.html~ tramite il pacchetto [[https://github.com/hexmode/ox-reveal][ox-reveal]].
   
** Youtube
   #+REVEAL: split
   Per gestire i vari video del canale ho un file ~.org~ apposito

   #+REVEAL_HTML: <img src="./images/youtube.png" class="scratch" height=450px;>
   
** Hack The Box
   #+REVEAL: split
   Per gestire gli appunti delle varie macchine su *Hack The Box* ho
   vari ~.org~ files.

   #+REVEAL_HTML: <div>
   
   #+REVEAL_HTML: <div class="column" style="float:left; width:50%">
   #+REVEAL_HTML: <img src="./images/htb_01.png" height=450px;>
   #+REVEAL_HTML: <p style="margin-top:-20px; font-size:20px;"> Main org-file </p>  
   #+REVEAL_HTML: </div>
   
   #+REVEAL_HTML: <div class="column" style="float:right; width:50%">
   #+REVEAL_HTML: <img src="./images/htb_02.png" height=450px;>
   #+REVEAL_HTML: <p style="margin-top:-20px; font-size:20px;"> Org-file per macchina </p>  
   #+REVEAL_HTML: </div>
   
   #+REVEAL_HTML: </div>
 
* The Org-Mode Markup Language
  #+REVEAL: split
  Gli elementi principali che formano la *org-mode markup language* sono
  molto semplici, e possono essere visualizzati a seguire

  #+begin_example
,* This Is A Heading
,** This Is A Sub-Heading
,*** And A Sub-Sub-Heading
    Paragraphs are separated by at least one empty line.
    
    ,*bold* /italic/ _underlined_ +strikethrough+ =monospaced=
    [[http://Karl-Voit.at][Link description]]
    http://Karl-Voit.at → link without description

    - list item
      - sub-item
	1. also enumerated
    - [ ] yet to be done
    - [X] item which is done

    : Simple pre-formatted text such as for source code.
  #+end_example

  #+REVEAL_HTML: <p style="margin-top:-15px; font-size:20px;"> Source:  <a href="https://karl-voit.at/2017/09/23/orgmode-as-markup-only/"> karl-voit - Org Mode Is One of the Most Reasonable Markup Languages to Use for Text </a> </p>

* Riferimenti
  #+REVEAL: split

  - [[https://orgmode.org/][orgmode]], official site.

  - [[https://orgmode.org/worg/][worg]], org-mode community resources.
  
  - [[https://www.youtube.com/watch?v=sQS06Qjnkcc&list=PLVtKhBrRV_ZkPnBtt_TD1Cs9PJlU0IIdE][Rainer König]], tutorial su org-mode.
